
# General utilities and practices

This repository contains development patterns 
applied for the bmcs packges. They distinguish 
three development phases:
 * Formulation of model components using using jupyter notebooks with Python package 
 * Implementation of Python packages
 * Model presentation using examples via Jupyter Notebooks 

The list of questions and answers related to pa

[Documentation](docs/README.md)

The notebook can be executed directly using the binder service. It takes a while for the repository image to build up.

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_utils/master?urlpath=%2Fapps%2Fbmcs_utils/test_editor.ipynb) - Start a simple example
